@@ -1,16 +1,19 @@
 #' Line specified by slope and intercept.
-#' 
+#'
 #' The abline geom adds a line with specified slope and intercept to the
 #' plot.
-#' 
+#'
 #' With its siblings \code{geom_hline} and \code{geom_vline}, it's useful for
-#' annotating plots.  You can supply the parameters for geom_abline, 
+#' annotating plots.  You can supply the parameters for geom_abline,
 #' intercept and slope, in two ways: either explicitly as fixed values, or
 #' in a data frame.  If you specify the fixed values
 #' (\code{geom_abline(intercept=0, slope=1)}) then the line will be the same
-#' in all panels.  If the intercept and slope are stored in the data, then 
+#' in all panels.  If the intercept and slope are stored in the data, then
 #' they can vary from panel to panel.  See the examples for more ideas.
 #'
+#' @section Aesthetics:
+#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("geom", "abline")}
+#'
 #' @seealso \code{\link{stat_smooth}} to add lines derived from the data,
 #'  \code{\link{geom_hline}} for horizontal lines,
 #'  \code{\link{geom_vline}} for vertical lines
@@ -29,10 +32,10 @@
 #' coef(lm(mpg ~ wt, data = mtcars))
 #' p + geom_abline(intercept = 37, slope = -5)
 #' p + geom_abline(intercept = 10, colour = "red", size = 2)
-#' 
+#'
 #' # See ?stat_smooth for fitting smooth models to data
 #' p + stat_smooth(method="lm", se=FALSE)
-#' 
+#'
 #' # Slopes and intercepts as data
 #' p <- ggplot(mtcars, aes(x = wt, y=mpg), . ~ cyl) + geom_point()
 #' df <- data.frame(a=rnorm(10, 25), b=rnorm(10, 0))
@@ -40,21 +43,21 @@
 #'
 #' # Slopes and intercepts from linear model
 #' library(plyr)
-#' coefs <- ddply(mtcars, .(cyl), function(df) { 
+#' coefs <- ddply(mtcars, .(cyl), function(df) {
 #'   m <- lm(mpg ~ wt, data=df)
-#'   data.frame(a = coef(m)[1], b = coef(m)[2]) 
+#'   data.frame(a = coef(m)[1], b = coef(m)[2])
 #' })
 #' str(coefs)
 #' p + geom_abline(data=coefs, aes(intercept=a, slope=b))
-#' 
+#'
 #' # It's actually a bit easier to do this with stat_smooth
 #' p + geom_smooth(aes(group=cyl), method="lm")
 #' p + geom_smooth(aes(group=cyl), method="lm", fullrange=TRUE)
-#' 
+#'
 #' # With coordinate transforms
 #' p + geom_abline(intercept = 37, slope = -5) + coord_flip()
 #' p + geom_abline(intercept = 37, slope = -5) + coord_polar()
-geom_abline <- function (mapping = NULL, data = NULL, stat = "abline", position = "identity", show_guide = FALSE, ...) { 
+geom_abline <- function (mapping = NULL, data = NULL, stat = "abline", position = "identity", show_guide = FALSE, ...) {
   GeomAbline$new(mapping = mapping, data = data, stat = stat, position = position, show_guide = show_guide, ...)
 }
 
@@ -66,7 +69,7 @@ GeomAbline <- proto(Geom, {
     class(mapping) <- "uneval"
     .super$new(., ..., mapping = mapping, inherit.aes = FALSE)
   }
-  
+
   draw <- function(., data, scales, coordinates, ...) {
     ranges <- coord_range(coordinates, scales)
 
@@ -78,16 +81,15 @@ GeomAbline <- proto(Geom, {
     GeomSegment$draw(unique(data), scales, coordinates)
   }
 
-  icon <- function(.) linesGrob(c(0, 1), c(0.2, 0.8))
   guide_geom <- function(.) "abline"
 
   default_stat <- function(.) StatAbline
   default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = NA)
-  
+
   draw_legend <- function(., data, ...) {
     data <- aesdefaults(data, .$default_aes(), list(...))
 
-    with(data, 
+    with(data,
       ggname(.$my_name(), segmentsGrob(0, 0, 1, 1, default.units="npc",
       gp=gpar(col=alpha(colour, alpha), lwd=size * .pt, lty=linetype,
         lineend="butt")))
