@@ -11,36 +11,36 @@ NULL
 #' @export
 #' @rdname plot-templates
 ggpcp <- function(data, vars=names(data), ...) {
-  gg_dep("0.9.1", "ggpcp")
+  gg_dep("0.9.1", "ggpcp is deprecated.")
 }
 
 #' @export
 #' @rdname plot-templates
 ggfluctuation <- function(table, type="size", floor=0, ceiling=max(table$freq, na.rm=TRUE)) {
-  gg_dep("0.9.1", "ggfluctuation")
+  gg_dep("0.9.1", "ggfluctuation is deprecated.")
 }
 
 #' @export
 #' @rdname plot-templates
 ggmissing <- function(data, avoid="stack", order=TRUE, missing.only = TRUE) {
-  gg_dep("0.9.1", "ggmissing")
+  gg_dep("0.9.1", "ggmissing is deprecated.")
 }
 
 #' @export
 #' @rdname plot-templates
 ggstructure <- function(data) {
-  gg_dep("0.9.1", "ggstructure")
+  gg_dep("0.9.1", "ggstructure is deprecated.")
 }
 
 #' @export
 #' @rdname plot-templates
 ggorder <- function(data) {
-  gg_dep("0.9.1", "ggorder")
+  gg_dep("0.9.1", "ggorder is deprecated.")
 }
 
 #' @export
 #' @rdname plot-templates
 plotmatrix <- function(data, mapping=aes(), colour="black") {
-  gg_dep("0.9.2", "Please use GGally::ggpairs.")
+  gg_dep("0.9.2", "This function is deprecated. For a replacement, see the ggpairs function in the GGally package.")
 }
 
